searchData={"items":[{"type":"module","title":"Scrivener.Components","doc":"Pagination `Phoenix.Component` for the `Scrivener` library, compatible with Phoenix 1.7 and LiveViews.\n\n_This library is an alternative to [`scrivener_html`](https://github.com/mgwidmann/scrivener_html), which is no longer actively maintained and is not compatible with Phoenix 1.7 and live views (numerous forks have sprung up to correct this by including a dependency on `phoenix_html_helpers`...). It reuses part of the `scrivener_html` code, but it relies on `Phoenix.Component` to generate the pagination HTML code._","ref":"Scrivener.Components.html"},{"type":"module","title":"Setup - Scrivener.Components","doc":"Add `:scrivener_components` to your project's dependencies:\n\n```elixir\ndef deps do\n  [\n    {:scrivener_components, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDepending on the CSS framework you use, import the component in your view.\n\n```elixir\ndefp html_helpers do\n  quote do\n    # ...\n    # Import the pagination component for your CSS framework\n    import Scrivener.Components.BootstrapV5\n  end\nend\n```\n\nAvailable framworks / modules:\n\n* Bootstrap V5: `Scrivener.Components.BootstrapV5`\n* That's all for now...","ref":"Scrivener.Components.html#module-setup"},{"type":"module","title":"Usage - Scrivener.Components","doc":"Use in your template:\n\n```elixir\n<.pagination page={page} url_params={[{\"q\", \"term\"}]} path={&~p\"/index?#{&1}\"} />\n```\n\nYou may customize and translate texts:\n\n```elixir\n<.pagination\n  page={page}\n  url_params={[{\"q\", \"term\"}]}\n  path={&~p\"/posts?#{&1}\"}\n  navigation_mode={:patch}\n  options={[\n    next: gettext(\"Next\"),\n    previous: gettext(\"Previous\")\n  ]} />\n  data-custom-attr=\"hello\"\n```\n\nWhere:\n\n* `page` is a `%Scrivener.Page{}` struct returned from `Repo.paginate/2`\n* `url_params` is a list of tuples for the query parameters that will persist accross pagination (typically the current search, filter and/or sort parameters)\n* `path` is a 1-arity function that receive the `url_params` merged with the current page number (`page`) and return the path. Typically a verified route sigil like `&~p\"/index?#{&1}\"`\n* `navigation_mode` is an `Atom`, to control the link component navigation mode, can be `:navigate`, `:patch` or `:href` (default: `:navigate`)\n* `options` is a `Keyword` list that can be used to customize the behaviour of the pagination:\n  - `previous`: the text displayed for the previous link (default: `<<`)\n  - `next`: the text displayed for the previous link (default: `>>`)\n  - `first`:\n    - if `true` (default), display always display the first page link,\n    - if a `:string`, replace the page number (1) with the text (ex: `First`)\n    - if `false`, the first page is not displayed (if it is not in the distance from the current page...)\n  - `last`:\n    - if `true` (default), display always display the last page link,\n    - if a `:string`, replace the last page number with the text (ex: `Last`)\n    - if `false`, the last page is not displayed (if it is not in the distance from the current page...)\n  - `ellipsis`: the text to display when number of page is more than the distance, (default: `raw(\"&hellip;\")`)\n  - `distance`: the maximum number of page links around the current page to display in the pagination (default: `5`)\n* You may add additionals attributes to the pagination component (for JS integration for instance)","ref":"Scrivener.Components.html#module-usage"},{"type":"module","title":"Scrivener.Components.BootstrapV5","doc":"Bootstrap 5 pagination component for the Scrivener library\n\nBased on https://getbootstrap.com/docs/5.3/components/pagination/#overview\n\nRenders the following structure:\n\n     \n       \n          Previous  \n          1  \n          2  \n          3  \n          …  \n          Next","ref":"Scrivener.Components.BootstrapV5.html"},{"type":"function","title":"Scrivener.Components.BootstrapV5.pagination/1","doc":"Renders a pagination component","ref":"Scrivener.Components.BootstrapV5.html#pagination/1"},{"type":"function","title":"Examples - Scrivener.Components.BootstrapV5.pagination/1","doc":"<.pagination page={@page} url_params={[\"q\", \"term\"]} path={&~p\"/index?#{&1}\"} />","ref":"Scrivener.Components.BootstrapV5.html#pagination/1-examples"},{"type":"function","title":"Attributes - Scrivener.Components.BootstrapV5.pagination/1","doc":"* `page` (`Scrivener.Page`) (required) - a `%Scrivener.Page{}` struct returned from `Repo.paginate/2`.\n* `url_params` (`:list`) - a list of tuples for the query parameters that will persist accross pagination (typically the current search, filter and/or sort parameters). Defaults to `[]`.\n* `page_param` (`:string`) - Defaults to `\"page\"`.\n* `path` (`:any`) (required) - a 1-arity function that receives the `url_params` merged with the current page number (`page`) and return the path. Typically a verified route sigil.\n* `navigation_mode` (`:atom`) - the link component navigation mode. Defaults to `:navigate`.\n* `options` (`:any`) - a `Keyword` list that can be used to customize the behaviour of the pagination. See `Scrivener.Components.PaginationLinks` defaults. Defaults to `[]`.\n* Global attributes are accepted.","ref":"Scrivener.Components.BootstrapV5.html#pagination/1-attributes"},{"type":"module","title":"Scrivener.Components.PaginationLinks","doc":"","ref":"Scrivener.Components.PaginationLinks.html"},{"type":"function","title":"Scrivener.Components.PaginationLinks.defaults/0","doc":"","ref":"Scrivener.Components.PaginationLinks.html#defaults/0"},{"type":"function","title":"Scrivener.Components.PaginationLinks.raw_pagination_links/2","doc":"Returns the raw data in order to generate the proper HTML for pagination links. Data\nis returned in a `{text, page_number}` format where `text` is intended to be the text\nof the link and `page_number` is the page it should go to. Defaults are already supplied\nand they are as follows:\n\n[distance: 5, next: \">>\", previous: \"<<\", first: true, last: true, ellipsis: {:safe, \"&hellip;\"}]\n\n`distance` must be a positive non-zero integer or an exception is raised. `next` and `previous` should be\nstrings but can be anything you want as long as it is truthy, falsey values will remove\nthem from the output. `first` and `last` are only booleans, and they just include/remove\ntheir respective link from output. An example of the data returned:\n\n    iex> Scrivener.HTML.raw_pagination_links(%{total_pages: 10, page_number: 5})\n    [{\"<<\", 4}, {1, 1}, {2, 2}, {3, 3}, {4, 4}, {5, 5}, {6, 6}, {7, 7}, {8, 8}, {9, 9}, {10, 10}, {\">>\", 6}]\n    iex> Scrivener.HTML.raw_pagination_links(%{total_pages: 20, page_number: 10}, first: [\"←\"], last: [\"→\"])\n    [{\"<<\", 9}, {[\"←\"], 1}, {:ellipsis, {:safe, \"&hellip;\"}}, {5, 5}, {6, 6},{7, 7}, {8, 8}, {9, 9}, {10, 10}, {11, 11}, {12, 12}, {13, 13}, {14, 14},{15, 15}, {:ellipsis, {:safe, \"&hellip;\"}}, {[\"→\"], 20}, {\">>\", 11}]\n\nSimply loop and pattern match over each item and transform it to your custom HTML.","ref":"Scrivener.Components.PaginationLinks.html#raw_pagination_links/2"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}